@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>
     SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
 
     SPDX-License-Identifier: LGPL-2.1-or-later
@@ -24,7 +24,6 @@ EmptyTrashCommand::EmptyTrashCommand(const QAbstractItemModel *model, QObject *p
     : CommandBase(parent)
     , mModel(model)
     , the_trashCollectionFolder(-1)
-    , mNumberOfTrashToEmpty(0)
 {
 }
 
@@ -33,7 +32,6 @@ EmptyTrashCommand::EmptyTrashCommand(const Akonadi::Collection &folder, QObject
     , mModel(nullptr)
     , the_trashCollectionFolder(-1)
     , mFolder(folder)
-    , mNumberOfTrashToEmpty(0)
 {
 }
 
@@ -90,7 +88,7 @@ void EmptyTrashCommand::execute()
 void EmptyTrashCommand::expunge(const Akonadi::Collection &col)
 {
     if (col.isValid()) {
-        Akonadi::ItemDeleteJob *jobDelete = new Akonadi::ItemDeleteJob(col, this);
+        auto *jobDelete = new Akonadi::ItemDeleteJob(col, this);
         connect(jobDelete, &Akonadi::ItemDeleteJob::result,
                 this, [this, jobDelete]() {
                     if (jobDelete->error()) {
